@@ -6,9 +6,12 @@ def start_server():
     :return: None
     """
     print("String server @", time.time())
-    x = input("Enter done to exit")
-    if x == "done":
-        exit(0)
+    while True:
+        x = input("Enter d to exit")
+        if x == "d":
+            break
+        else:
+            print("You just entered: ", x)
 
 
 if __name__ == "__main__":
